# decision surface for logistic regression on a binary classification dataset
import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.neighbors import KNeighborsClassifier
from sklearn.metrics import confusion_matrix
import matplotlib.pyplot as plt

# Leemos los datos del archivo
D = np.loadtxt("iris.csv", delimiter=',', skiprows=1, max_rows=100 )
print( D.shape )

# Tenemos que separar los datos en datos para el
# entrenamiento del modelo y datos
# para probar el modelo

X = D[:,0:2]
#       0 <= i < 4
y = D[:,4]

X_entrena, X_prueba, y_entrena, y_prueba = train_test_split( X, y, random_state=10)

# define bounds of the domain
min1, max1 = 4, 7.5
min2, max2 = 2, 4.5 

# define the x and y scale
x1vec = np.arange(min1, max1, 0.1)
x2vec = np.arange(min2, max2, 0.1)

# create all of the lines and rows of the grid
xx, yy = np.meshgrid(x1vec, x2vec)

# flatten each grid to a vector
r1, r2 = xx.flatten(), yy.flatten()
r1, r2 = r1.reshape((len(r1), 1)), r2.reshape((len(r2), 1))

# horizontal stack vectors to create x1,x2 input for the model
grid = np.hstack((r1,r2))

# define the model
clasificador = KNeighborsClassifier(n_neighbors=1)

# fit the model
clasificador.fit(X_entrena, y_entrena)

y_predichas = clasificador.predict( X_prueba )
matriz = confusion_matrix( y_prueba, y_predichas )
print( matriz )

# make predictions for the grid
yhat = clasificador.predict(grid)
# reshape the predictions back into a grid
zz = yhat.reshape(xx.shape)

fig, ex = plt.subplots( )

# plot the grid of x, y and z values as a surface
ex.contourf(xx, yy, zz, cmap='Paired')
# create scatter plot for samples from each class
for class_value in range(2):
	# get row indexes for samples with this class
	row_ix = np.where(y_prueba == class_value)
	# create scattr of these samples
	ex.scatter(X_prueba[row_ix, 0], X_prueba[row_ix, 1], cmap='Paired')

# show the plot
plt.show()

